<?php


/** 
 * Page callback to view the contents of a Daylife Feed.
 *
 * @param $id
 *   daylife_feed_id
 * @return
 *   html page output to be rendered in theme.
 */
function daylife_feed_page($feed) {
  $items = $feed->get_paged_data();
  $output = '';
  if (empty($items)) return t('There are no unimported items for this feed.');
  foreach($items as $item) {
    $output .= theme('daylife_item', $item);
  }
  return $output . theme('pager');
}

/**
 * Page Call back to update a feed cache.
 */
function daylife_admin_feed_update_page($feed, $destination) {
  $feed->update_cache(true);
  drupal_goto($destination);
}

/**
 * add form to create a daylife feed.
 */
function daylife_feed_form($feed = false, $path = '') {
  global $user;
  // request daylife stories to validate keys
  $daylife = daylife::instance();
  $test = $daylife->request('topic_getRelatedStories', array('name=daylife'), 'name');
  if (!isset($test->response->code) || $test->response->code == -2001) {
    $replacements = array(
      '!configured' => l('configured', 'admin/settings/daylife')
    );  
    return array('need_settings' => array(
      '#type' => 'markup',
      '#value' => t('The Daylife module must be properly !configured before you can add feeds.', $replacements),
    ));  
  }

  if (!$feed) $feed = new daylifeFeed();
  drupal_add_js(drupal_get_path('module', 'daylife') .'/daylife_feed_form.js');
  drupal_add_css(drupal_get_path('module', 'daylife') .'/daylife_feed_form.css');
 
  $form = array();
  $form['daylife_feed_id'] = array(
    '#type' => 'hidden',
    '#value' => $feed->id,
  );

  $form['name'] = array(
    '#title' => t('Feed Name'),
    '#description' => t('A human readable name for this feed.'),
    '#type' => 'textfield',
    '#default_value' => $feed->name,
  );

  if (user_access('adminster daylife feeds')) {
    $account = ($feed->uid) ? user_load(array('uid' => $feed->uid)) : $user;
    $form['uid'] = array(
      '#title' => t('Feed owner'),
      '#description' => t('The user automatically imported content will appear as
                       being posted by. This user will have the ability to 
                       administer the daylife imported nodes.'),
      '#type' => 'textfield',
      '#default_value' => ($account) ? $account->name : $user->name,
      '#autocomplete_path' => 'user/autocomplete',
    );  
  }
  else {
   $form['uid'] = array(
    '#type' => 'value',
    '#value' => $user->name,
   );
  }  
  
 
  if (!user_access('administer daylife feeds') && !($user->uid == $feed->uid)) {
    $form['uid']['#type'] = 'hidden';
    
  }  
  
  $form['type'] = array(
    '#title' => t('Feed Type'),
    '#description' => t('<strong>Topic</strong> feeds allow you to select from an ever growing set of topics on Daylifei derived from its aggregated content. Query feeds give you a more powerful and flexible query language to use with the DayPI.'),
    '#type' => 'select',
    '#options' => array(
      DAYLIFE_FEED_TYPE_TOPIC => t('Topic'), 
      DAYLIFE_FEED_TYPE_SEARCH => t('Search'),
    ),
    '#default_value' => $feed->type,
  );


  $vid = variable_get('daylife_topic_vocab', 0);
  $form['topics'] = array(
    '#title' => t('Topics'),
    '#description' => t('Enter a comma seperated list of topics for this feed'),
    '#type' => 'textfield',
    '#autocomplete_path' => 'taxonomy/autocomplete/'. $vid,
    '#default_value' =>  $feed->topics,
  );

  $form['query'] = array(
    '#title' => t('Search Query'),
    '#description' => t('@todo: simple  query doc.'),
    '#type' => 'textfield',
    '#default_value' => $feed->query,
  );

  $form['query_help'] = array(
    '#title' => t('Query Syntax'),
    '#description' => t('A query is broken up into terms and boolean operators'),
    '#type' => 'fieldset',
    '#value' => daylife_search_help(),
    '#collapsible' => true,
    '#collapsed' => true,
    '#attributes' => array('id' => 'edit-query-help'),
  );

  $form['item_types'] = array(
    '#prefix' => '<div class="daylife-feed-includes"><label>Include:</label><div class="description">Daylife content types to be included in this feed.</div>',
    '#suffix' => '</div>',
    '#tree' => true,
  );

  $form['item_types']['article'] = array(
    '#title' => t('Articles'),
    '#type' => 'checkbox',
    '#default_value' => $feed->item_types['article'],
  );

  $form['item_types']['quote'] = array(
    '#title' => t('Quotes'),
    '#type' => 'checkbox',
    '#default_value' => $feed->items_types['quote'],
  );


  $form['item_types']['image'] = array(
    '#title' => t('Images'),
    '#type' => 'checkbox',
    '#default_value' => $feed->items_types['image'],
  );
  if (!($feed->source_filter || variable_get('daylife_source_filter_id', ''))) {
    $form['item_types']['image']['#disabled'] = true;
    $form['item_types']['image']['#default_value'] = 0;
    $form['item_types']['image']['#description'] = t('Images cannot be included without a valid source filter id. 
      You can set source filters per feed or you can set the global source filter at !link.', 
      array('!link' => l('admin/settings/daylife', 'admin/settings/daylife')));

  }


  $form['advanced'] = array(
    '#title' => t('Advanced Feed Options'),
    '#type' => 'fieldset',
    '#collapsible' => true,
    '#collapsed' => false,
  );
  
  $form['advanced']['import'] = array(
    '#title' => t('Auto Import'),
    '#description' => t('Automatically import feed items as nodes.'),
    '#type' => 'checkbox',
    '#default_value' => $feed->import,
  );

   

  $form['advanced']['spider_topic'] = array(
    '#title' => t('Enable Topic Spidering'),
    '#description' => t('Query related topics for additional content and include in the feed.'),
    '#type' => 'checkbox',
    '#default_value' => $feed->spider_topic,
  );

  $form['advanced']['spider_depth'] = array(
    '#title' => t('Spider Depth'),
    '#description' => t('Depth of related topics to search.'),
    '#type' => 'select',
    '#options' => array(1=>1,2=>2,3=>3, 4=>4,5=>5),
    '#default_value' => $feed->spider_depth,
  ); 

  $form['advanced']['spider_types'] = array(
    '#title' => t('Spider Topic Types'),
    '#description' => t('Select the types of topics to spider.'),
    '#type' => 'checkboxes',
    '#options' => array('PLACE' => t('Place'), 'ORGANIZATION' => t('Organization'), 'PERSON' => t('Person'), 
                        'HOLIDAY' => t('Holiday'), 'DRUG' => t('Drug'), 'DISEASE' => t('Disease'), 
                        'STATION' => t('Station')),
    '#default_value' => $feed->spider_types,
  ); 
  
  $form['advanced']['cache_update'] = array(
    '#title' => t('Cache Update Period'),
    '#description' => t('The period for cache updates in seconds.'),
    '#type' => 'textfield',
    '#default_value' => $feed->cache_update,
  );
   
  // oldest items to keep in cache. 
  $form['advanced']['cache_expiry'] = array(
    '#title' => t('Cache Expiry'),
    '#description' => t('The longest and item will be stored in the cache, before it is reloaded.'),
    '#type' => 'textfield',
    '#default_value' => $feed->cache_expiry,
  );
  
  $form['advanced']['source_filter'] = array(
    '#title' => t('Source Filter ID'),
    '#description' => t('The global source filter entered on !admin will be 
                         used if the feed source filter is empty.', 
                         array('!admin' => l('admin/settings/daylife','admin/settings/daylife'))),
    '#type' => 'textfield',
    '#size' => 16,
    '#default_value' => $feed->source_filter,
  );


  $form['submit'] = array(
    '#value' => t('Save Feed'),
    '#type' => 'submit',
  );

  $form['#validate'] = array('daylife_feed_form_validate' => array());
  $form['path'] = array(
    '#type' => 'value', 
    '#value' => $path,
  );
  return $form;
}

function daylife_feed_form_validate($id, $values) {
  if (!$account = user_load(array('name' => $values['uid']))) {
    form_set_error('import_user', t('The import user does not exist.'));
  }   
  // convert username back to uid.
  $values['uid'] = $account->uid;
  if (!$feed = new daylifeFeed($values)) {
    form_set_error($id, t('Feed Validation: Invalid input instantiation error.'));
  }
 
  $errors = $feed->validate();
  foreach($errors as $property => $message) {
    form_set_error($property, $message);
  }
}

function daylife_feed_form_submit($id, $values) {
  $account = user_load(array('name' => $values['uid']));
  $values['uid'] = $account->uid;
  $feed = new daylifeFeed($values);
  $feed->save();
  drupal_set_message('You Daylife Feed has been created.');
  return $values['path'];
};


/**
 * form to delete a daylife feed.
 */
function daylife_feed_delete_form($feed, $path) {
  $form['daylife_feed_id'] = array(
    '#type' => 'hidden',
    '#value' =>  $feed->id,
  );  
  $form['path'] = array(
    '#type' => 'value',
    '#value' => $path,
  );  
  $replacements = array('%name' => $feed->name);
  return confirm_form($form, 
                       t("Are you sure you want to delete the feed '%name'?", 
                         $replacements), 
                      $path, 
                      t("This will remove the feed and empty it's cache. It will 
                         not affect any content imported from the feed."), 
                      t('Delete'), 
                      t('Cancel'), 
                      'daylife_feed_delete_confirm');
}

function daylife_feed_delete_form_submit($id, $values) {
  $feed = new daylifeFeed($values['daylife_feed_id']);
  $feed->delete();
  unset($feed);
  return $values['path'];
}

/**
 * form to delete a daylife feed.
 */
function daylife_feed_reset_form($feed, $destination) {
  $form['daylife_feed_id'] = array(
    '#type' => 'hidden',
    '#value' =>  $feed->id,
  );  
  $form['destination'] = array(
    '#type' => 'value',
    '#value' => $destination,
  );  
 
  $replacements = array('%name' => $feed->name);
  return confirm_form($form, 
                      t("Are you sure you want to reset the feed '%name'?", 
                        $replacements), 
                      $destination,
                      t("This will clear the feed's cache. Older feed items
                         will be lost permanently. Imported Daylife content 
                         will be unaffected."),
                      t('Reset'), 
                      t('Cancel'), 
                      'daylife_feed_reset_confirm');
}

function daylife_feed_reset_form_submit($id, $values) {
  $feed = new daylifeFeed($values['daylife_feed_id']);
  $feed->reset_cache();
  return $values['destination'];
}

