<?php

// common load function for daylife items.
function _daylife_node_load($node) {
  $result =  db_query('SELECT * FROM {daylife_node} WHERE vid=%d', $node->nid);
  $additions = db_fetch_object($result);
  $additions->daylife_item = daylife_item($additions->daylife_id, $additions->daylife_type);
  $additions->article = daylife_item($additions->article, 'article');
  $additions->source = daylife_source($additions->source);
  return $additions;
}

// common prepare function for daylife items.
function _daylife_node_prepare(&$node) {
  // no prepare for existing nodes.
  if (!empty($node->nid)) {
    return false;
  }
  
  $node->daylife_type = substr($node->type, 8);
  if (isset($_REQUEST['daylife_id'])) {
    $node->daylife_id = check_plain($_REQUEST['daylife_id']);
  }
  if (isset($_REQUEST['daylife_feed']) && $feed = new daylifeFeed($_REQUEST['daylife_feed'])) {
    $node->daylife_feed = $feed->id;
    $node->uid = $feed->uid;
    $account = user_load(array('uid' => $node->uid));
    $node->name = $account->name;
  }  

  
  // daylife_id must be set.
  if (empty($node->daylife_id)) {
    return false;
  }
 
  // get out and unset daylife_id if it is invalid.
  if (!$node->daylife_item = daylife_item($node->daylife_id, $node->daylife_type)) {
    unset($node->daylife_id);
    return false;
  }  
  return true;
}

// common form function for daylife items.
function _daylife_node_form(&$node, $form_values) {
  $form = node_content_form($node);
  $form['daylife_id'] = array(
    '#title' => t('Daylife ID'),
    '#type' => 'textfield',
    '#default_value' => $node->daylife_id,
    '#weight' => -8,
    '#size' => 32,
  );
  if (isset($node->daylife_id)) {
     $form['daylife_id']['#value'] =  $node->daylife_id;
  }   
  $form['daylife_feed'] = array(
    '#type' => 'hidden',
    '#value' => $node->daylife_feed,
  );  
  $form['daylife_timestamp'] = array(
    '#title' => t('Use Daylife Timestamp'),
    '#description' => t('Use the timestamp for the daylife article as the node created time, instead of the import time.'),
    '#type' => 'checkbox',
    '#default_value' => 1,
  );  
  $form['daylife_url'] = array(
    '#title' => t('Daylife URL'),
    '#type' => 'item',
    '#value' => l($node->daylife_item->daylife_url, $node->daylife_item->daylife_url),
    '#weight' => -8,
    '#theme' => 'item',
  );
  $form['daylife_type'] = array(
    '#type' => 'hidden',
    '#value' => substr($node->type, 8),
  );  
  if (isset($node->daylife_id)) {
    $form['daylife_id']['#value'] =  $node->daylife_id;
  }   
  return $form;
}

function _daylife_node_form_alter(&$form) {
  // protect taxonomy from user manipulation.
  $vid = variable_get('daylife_topic_vocab', 0);
  unset($form['taxonomy'][$vid]);

  // overide default body settings.
  $form['body_filter']['body']['#disabled'] = true;
  $form['body_filter']['body_filter']['#default_value'] = 1;
  $form['body_filter']['body_filter']['#disabled'] = true;

  // override default title settings.
  $form['title']['#required'] = false;
  $form['title']['#disabled'] = true;
}  

function _daylife_node_validate(&$node, $form) {
  if (!$node->daylife_item = daylife_item($node->daylife_id, $node->daylife_type)) {
    form_set_error('daylife_id', t('Invalid Daylife ID for %type', 
                    array('%type' => ucfirst($node->daylife_type))));
    return false;                 
  }                  
  return true;
}

function _daylife_node_submit(&$node) {
  $daylife_type = substr($node->type, 8);
  $item = daylife_item($node->daylife_id, $daylife_type);
  foreach($item->topics as $topic) {
    $terms = taxonomy_get_term_by_name($topic->name);
    $node->taxonomy[]  = $terms[0]->tid;
  }

  // set date.
  if ($node->daylife_timestamp) {
    $node->date =  $item->timestamp;
  }
}   

function _daylife_node_insert($node) {
  $item = daylife_item($node->daylife_id, $daylife_type);
  db_query("INSERT INTO {daylife_node} (nid, vid, daylife_feed, daylife_id)
            VALUES (%d, %d, %d, '%s')",
            $node->nid, $node->vid, $node->daylife_feed, $node->daylife_id);
}
 
function _daylife_node_delete($node) {
  db_query('DELETE FROM {daylife_node} WHERE nid=%d', $node->nid); 
}

/**
 * @defgroup DayLife Article Node Hooks
 * @{
 */
 
function daylife_article_prepare(&$node) {
  _daylife_node_prepare($node);
  if (isset($node->daylife_id)) {
    $node->title = _daylife_title($node->daylife_item->excerpt);
    $node->body = $node->daylife_item->excerpt;
  }
}

function daylife_article_form(&$node, $form_values) {
  drupal_set_title('Import Daylife Article');

  if (empty($node->title)) $node->title = 'Daylife Article Headline will be imported here.';
  if (empty($node->body)) $node->body = 'Daylife Article Excerpt will be imported here.';

  $form = _daylife_node_form($node, $form_values);
  $form['original_url_markup'] = array(
    '#title'=> t('Original URL'),
    '#type' => 'item',
    '#value' => l($node->daylife_item->original_url, $node->daylife_item->original_url),
    '#weight' => -8,
  );
  return $form;
}

function daylife_article_node_form_form_alter(&$form) {
  _daylife_node_form_alter($form);
}

function daylife_article_validate($node, &$form) {
  _daylife_node_validate($node, $form);
}

function daylife_article_submit(&$node) {
   _daylife_node_submit($node);
}

function daylife_article_insert($node) {
  _daylife_node_insert($node);
}

function daylife_article_load($node) {
  return _daylife_node_load($node);
}

function daylife_article_delete($node) {
  _daylife_node_delete($node);
}

/**
 * @} End defgroup DayLife Article Node Hooks
 */

/**
 * @defgroup DayLife Quote Node Hooks
 * @{
 */

function daylife_quote_prepare(&$node) {
  _daylife_node_prepare($node);
  if (isset($node->daylife_id)) {
    $node->title = _daylife_title($node->daylife_item->quote_text);
    $node->body = $node->daylife_item->quote_text;
  }  
}

function daylife_quote_form(&$node, $form_values) {
  if (empty($node->title)) $node->title = 'Daylife Quote will be imported here.';
  if (empty($node->body))  $node->body = 'Daylife Quote will be imported here.';

  $form = _daylife_node_form($node, $form_values);
  
  return $form;
}

function daylife_quote_node_form_form_alter(&$form) {
  _daylife_node_form_alter($form);
}

function daylife_quote_validate($node, &$form) {
  _daylife_node_validate($node, $form);
}

function daylife_quote_insert($node) {
  _daylife_node_insert($node);
}

function daylife_quote_load($node) {
  return _daylife_node_load($node);
}

function daylife_quote_submit(&$node) {
  _daylife_node_submit($node);
}

function daylife_quote_view($node, $teaser = false, $page=false) {
  $node = node_prepare($node, $teaser);
  //$node->title = strip_tags($node->content['body']['#value']);
  $node->content['body']['#type'] = 'item';
  $node->content['body']['#title'] = t('Complete Quote');

  // add element #type (daylife_speaker, daylife_article_cite);
  $node->content['daylife_speaker'] = array(
    '#type' => 'item',
    '#title' => t('Speaker'),
    '#value' =>  l($node->daylife_item->name, $node->daylife_item->topic->daylife_url),
  );
  $node->content['daylife_article'] = array(
    '#type' => 'item',
    '#title' => t('Original Article'),
    '#value' => l($node->daylife_item->source->name, $node->daylife_item->source->url) .': '. l($node->daylife_item->article->headline, $node->daylife_item->article->url),
  );
  return $node;
}  

function daylife_quote_delete($node) {
  _daylife_node_delete($node);
}

/**
 * @} End defgroup DayLife Quote Node Hooks
 */


/**
 * @defgroup DayLife Image Node Hooks
 * @{
 */

function daylife_image_prepare(&$node) {
  _daylife_node_prepare($node);
  if (!isset($node->daylife_id)) return;
  $node->title = _daylife_title($node->daylife_item->caption);
  $node->body =  $node->daylife_item->caption;
}

function daylife_image_form(&$node, $form_values) {
  if (empty($node->title)) $node->title = 'Daylife Image will be imported here.';
  if (empty($node->body)) $node->body = 'Daylife Image will be imported here.';
  
  $form = _daylife_node_form($node, $form_values);
  if (!isset($node->daylife_id)) return $form;
  
  $image_url = _daylife_image_url($item, true);
  $form['image_view'] = array(
    '#type' => 'markup',
    '#value' => '<a href="'. $image_url .'"> <img src="'. $image->url .'" /></a>',
    '#weight' => -10,
    '#after_build' => array('_daylife_image_after_build'),
  );
  return $form;
} 

function daylife_image_node_form_form_alter(&$form) {
  _daylife_node_form_alter($form);
}

function daylife_image_validate($node, &$form) {
  _daylife_node_validate($node, $form);
  
  
  // skip file save section of validation if file is already saved.
  if (db_result(db_query("SELECT count(*) FROM {daylife_file} WHERE daylife_id='%s'", $node->daylife_id))) {
    return;
  }
  // create a directory hashed on date.
  $path = file_directory_path() .'/daylife/'. date('Y/j/d', $_SERVER['REQUEST_TIME']);
  // make sure directory exists.
  if (!file_check_directory($path) && !_daylife_mkdir($path)) {
    form_set_error('daylife_id', t('Unable to create directory(%path) for daylife image.', array('%path' => $path)));
    return;
  }

  // download a original size.
  $image_url =  DAYLIFE_IMGSRV . $node->daylife_id .'/'. $node->daylife_item->width .'x.jpg';
  if (!$contents = file_get_contents($image_url)) {
    form_set_error('daylife_id', 
                   t('Unable to retrieve daylife image(%url).', array('%url' => $image_url)));
    return;
  }
   
  $path .= '/'.  $node->daylife_id .'.jpg';
  if (!$fp = fopen($path, 'wb')) {
    form_set_error('daylife_id', t('The file could not be created.'));
    return;
  }
  fwrite($fp, $contents);
  fclose($fp);


  $fid =  db_next_id('{files}_fid');
  // @hack: we use a 0 nid for daylife items. to hide them from upload.module.
  db_query("INSERT INTO {files} (fid, nid, filename, filepath, filemime, filesize) 
            VALUES (%d, %d, '%s', '%s', '%s', %d)", 
            $fid, 0, basename($path), $path, 'image/jpeg', filesize($path));
  db_query("INSERT INTO {daylife_file} (daylife_id, fid) VALUES ('%s', %d)", 
            $node->daylife_id, $fid);

}

function daylife_image_insert($node) {
  _daylife_node_insert($node);
}

function daylife_image_load($node) {
  $additions = _daylife_node_load($node);
  $additions->daylife_file = db_fetch_object(db_query("SELECT * FROM {files} f JOIN {daylife_file} df ON f.fid = df.fid WHERE df.daylife_id='%s'", $additions->daylife_id));
  return $additions;
}

function daylife_image_view($node, $teaser = false, $page=false) {
  $node = node_prepare($node, $teaser);
  $image_url = _daylife_image_url($node, $teaser);
  $node->content['daylife_image'] = array(
    '#value' => '<img  src="'. $image_url .'" />',
  );

  return $node;
}

function daylife_image_delete($node) {
  _daylife_node_delete($node);
  if (file_delete($node->daylife_file->filepath)) {
    db_query('DELETE FROM {files} WHERE fid=%d', $node->daylife_file->fid);
    db_query("DELETE FROM {daylife_file} WHERE fid=%d",  $node->daylife_file->fid);
  }
  else {
    watchdog('daylife', t('File delete error. Delete manually. @todo: instructions.'), WATCHDOG_ERROR);
  }
}

/**
 * @} End defgroup DayLife Image Node Hooks
 */


/**
 * @} End defgroup DayLife Node Hooks.
 */


